
/* bus.cc */

#include "bus.h"

#include <QPushButton>
#include <QDBusConnection>

#include <kaboutdata.h>
#include <kaction.h>
#include <kpluginfactory.h>
#include <kactioncollection.h>

#include <ktexteditor/document.h>
#include <ktexteditor/view.h>

#include <interfaces/icore.h>
#include <interfaces/idocumentcontroller.h>
// #include <interfaces/iuicontroller.h>

#ifdef TRACEVIEW
   #include "traceview.h"
#endif

#include <iostream>

/* ----------------------------------------------------------------------- */

namespace Bus {

/* ----------------------------------------------------------------------- */

KAboutData aboutData ("bus", // application name
                      "bus", // catalog name
                      ki18n ("Bus Plugin"), // displayable program name
                      "0.1", // version
                      ki18n ("Simple commands from DBus"), // short description
                      KAboutData::License_GPL);

K_PLUGIN_FACTORY (BusPluginFactory, registerPlugin <BusPlugin> (); )
K_EXPORT_PLUGIN (BusPluginFactory (aboutData))

/* ----------------------------------------------------------------------- */

BusPlugin::BusPlugin (QObject *parent, const QVariantList & args) :
   KDevelop::IPlugin (BusPluginFactory::componentData(), parent)
   #ifdef TRACEVIEW
   , m_trace_factory (NULL)
   #endif
{
   Q_UNUSED(args)

   #if 1
      std::cout << std::endl;
      std::cout << " **** BUS INIT **** " << std::endl;
      std::cout << std::endl;
   #endif

   #if 1
      kDebug () << " ---- BUS INIT ---- ";
   #endif

   #ifdef TRACEVIEW
      m_trace_factory = new TraceViewFactory ();
      core()->uiController()->addToolView ("Bus Trace", m_trace_factory);
   #endif

   setXMLFile ("bus.rc");

   QDBusConnection::sessionBus().registerObject
      ("/org/kdevelop/BusPlugin", this, QDBusConnection::ExportScriptableSlots);

   KActionCollection * actions = actionCollection ();

   KAction * action = actions->addAction ("bus_run");
   action->setText (i18n ("Bus Plugin"));
   connect (action, SIGNAL (triggered (bool)), this, SLOT (run ()));

   trace (" .... BUS PLUGIN .... ");
}

BusPlugin::~BusPlugin()
{
}

void BusPlugin::unload()
{
   #ifdef TRACEVIEW
      core()->uiController()->removeToolView (m_trace_factory);
   #endif
}

/* ----------------------------------------------------------------------- */

void BusPlugin::run ()
{
   #if 0
      std::cout << std::endl;
      std::cout << " **** BUS RUN **** " << std::endl;
      std::cout << std::endl;
   #endif

   kDebug () << " ---- BUS RUN ---- ";

   trace ("... BUS RUN ....");
}

/* ----------------------------------------------------------------------- */

void BusPlugin::insertCode (QString url, QString text)
{
    trace ("insertCode (" + url + ", " + text + ")");

    KDevelop::IDocument* doc = KDevelop::ICore::self()->documentController()->documentForUrl (url);

    if (doc != NULL && doc->isTextDocument())
    {
       kDebug () << "inserting text";

       KTextEditor::Document* document = doc->textDocument();
       KTextEditor::Cursor cursor = document->documentEnd();
       document->insertText (cursor, text);

       if (document->activeView() != NULL)
          document->activeView()->setFocus();
    }
}

/* ----------------------------------------------------------------------- */

} // end of namespace

#include "bus.moc"
