
/* traceview.cc */

#include "traceview.h"

#include <QLabel>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QHeaderView>
#include <QMenu>

#include <KLocalizedString>
#include <KIcon>
#include <KIconLoader>
#include <KAction>

#include <iostream>

/* ----------------------------------------------------------------------- */

namespace Bus {

using namespace KDevelop;

static TraceViewWidget * g_trace = NULL;
static QTreeWidgetItem * g_current = NULL;

/* ----------------------------------------------------------------------- */

TraceViewWidget::TraceViewWidget(QWidget* parent) :
   QWidget (parent),
   m_tree (NULL),
   m_button (NULL),
   m_info_icon (),
   m_error_icon ()
{
   setObjectName("TraceView Tree");
   setWindowTitle(i18n("TraceView"));
   setWindowIcon(SmallIcon("code-class"));

   m_tree = new QTreeWidget (this);
   m_tree->header()->setResizeMode(0, QHeaderView::ResizeToContents);
   // m_tree->header()->setStretchLastSection(false);

   m_button = new QPushButton ("Click", this);
   connect (m_button, SIGNAL (clicked ()), this, SLOT (click ()));

   QVBoxLayout* vbox = new QVBoxLayout(this);
   vbox->setMargin(0);
   vbox->addWidget (m_button);
   vbox->addWidget(m_tree);
   setLayout( vbox );

   setWhatsThis( i18n( "TraceView" ) );

   connect (m_tree,
            SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)),
            this,
            SLOT(doubleClick(QTreeWidgetItem*,int)));


   m_info_icon = SmallIcon ("info");
   m_error_icon = SmallIcon ("emblem-important");

   m_action = new KAction (this);
   m_action->setText (i18n ("Action Click"));
   connect (m_action, SIGNAL (triggered (bool)), this, SLOT (click ()));

   g_trace = this;
   g_current = NULL;

   #if 0
   trace_open ("branch");
   trace ("sub item");
   trace_close ();
   trace ("next item");
   trace_alert ("alert");
   #endif
}

TraceViewWidget::~TraceViewWidget()
{
   g_trace = NULL;
   g_current = NULL;
}

/* ----------------------------------------------------------------------- */

void TraceViewWidget::contextMenuEvent (QContextMenuEvent* e)
{
   QMenu *menu = new QMenu (this);

   // Context* c;
   // QList<ContextMenuExtension> extensions = ICore::self()->pluginController()->queryPluginsForContextMenuExtensions( c );
   // ContextMenuExtension::populateMenu(menu, extensions);

   menu->addAction (m_action);

   if (!menu->actions().isEmpty())
     menu->exec(QCursor::pos());
}

void TraceViewWidget::click ()
{
   trace ("Click");
}

void TraceViewWidget::doubleClick (QTreeWidgetItem* item, int column)
{
   trace ("Double click");
}

/* ----------------------------------------------------------------------- */

QTreeWidgetItem * TraceViewWidget::show (QTreeWidgetItem * branch, QString text, bool alert)
{
   QTreeWidgetItem * item;
   if (branch == NULL)
   {
      item = new QTreeWidgetItem ();
      m_tree->addTopLevelItem (item);
   }
   else
   {
      item = new QTreeWidgetItem (branch);
   }

   item->setText (0, text);

   if (alert)
      item->setIcon (0, m_error_icon);
   else
      item->setIcon (0, m_info_icon);

   // item->setToolTip (0, decl->toString());

   return item;
}

/* ----------------------------------------------------------------------- */

void trace_start (QString text)
{
   g_current = NULL;
   trace_open (text);
}

void trace_open (QString text)
{
   if (g_trace != NULL)
      g_current = g_trace->show (g_current, text);
}

void trace_close ()
{
   if (g_current != NULL)
      g_current = g_current->parent ();
}

void trace (QString text)
{
   if (g_trace != NULL)
      g_trace->show (g_current, text);
}

void trace_alert (QString text)
{
   if (g_trace != NULL)
      g_trace->show (NULL, text, true);
}

/* ----------------------------------------------------------------------- */

} // end of namespace

#include "traceview.moc"
