
/* traceview.h */

#ifndef TRACEVIEW_H
#define TRACEVIEW_H

#include <interfaces/iuicontroller.h>
#include <language/duchain/ducontext.h>

#include <QtGui/QWidget>
#include <QtGui/QPushButton>
#include <QtGui/QTreeView>
#include <QtGui/QTreeWidget>

#include <KIcon>

/* ----------------------------------------------------------------------- */

namespace Bus {

/* ----------------------------------------------------------------------- */

void trace_start (QString text);

void trace_open (QString text);
void trace_close ();

void trace (QString text);

void trace_alert (QString text);

/* ----------------------------------------------------------------------- */

class TraceViewWidget : public QWidget
{
   Q_OBJECT

public:
   TraceViewWidget (QWidget* parent);
   virtual ~TraceViewWidget ();

   virtual void contextMenuEvent (QContextMenuEvent* e);
   QTreeWidgetItem * show (QTreeWidgetItem * branch, QString text, bool alert = false);

private Q_SLOTS:
   void click ();
   void doubleClick (QTreeWidgetItem* item, int column);

private:
   QTreeWidget * m_tree;
   QPushButton * m_button;
   KAction * m_action;
   QIcon m_info_icon;
   QIcon m_error_icon;
};

/* ----------------------------------------------------------------------- */

class TraceViewFactory: public KDevelop::IToolViewFactory
{
public:
   virtual QWidget* create (QWidget *parent = 0)
   {
       m_widget = new TraceViewWidget (parent);
       return m_widget;
   }

   virtual Qt::DockWidgetArea defaultPosition ()
   {
       return Qt::BottomDockWidgetArea;
   }

   virtual QString id () const
   {
       return "org.kdevelop.Bus.TraceView";
   }

private:
   TraceViewWidget * m_widget;

public:
   TraceViewFactory () : m_widget (NULL) { }
};

/* ----------------------------------------------------------------------- */

} // end of namespace

#endif // TRACEVIEW_H
